#
# spec file for package perl-libintl-perl
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name libintl-perl
Name:           perl-libintl-perl
Version:        1.33
Release:        1.7
#Upstream: CHECK(Artistic-1.0 or GPL-1.0-or-later)
License:        GPL-3.0-or-later
Summary:        High-Level Interface to Uniforum Message Translation
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/G/GU/GUIDO/%{cpan_name}-%{version}.tar.gz
Source1:        libintl-perl-rpmlintrc
Source2:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(version) >= 0.77
Requires:       perl(version) >= 0.77
Recommends:     perl(File::ShareDir)
%{perl_requires}
# MANUAL BEGIN
Requires:       gettext-runtime >= 0.12.2
# MANUAL END

%description
This is an internationalization library for Perl that aims to be
compatible with the Uniforum message translations system as implemented
for example in GNU gettext.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes Credits FAQ NEWS README README.md README-oldversions README.solaris README.win32 REFERENCES THANKS TODO
%license COPYING

%changelog
* Thu Dec 15 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.33
  see /usr/share/doc/packages/perl-libintl-perl/Changes
  Version 1.33 - 14 Dec 2020
  * Bugs fixed:
    https://github.com/gflohr/libintl-perl/issues/7
* Tue Oct 27 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.32
  see /usr/share/doc/packages/perl-libintl-perl/Changes
  Version 1.32 - 26 Oct 2020
  * Bugs fixed:
    https://github.com/gflohr/libintl-perl/issues/5
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.31
  see /usr/share/doc/packages/perl-libintl-perl/Changes
  Version 1.31 - 19 Nov 2018
  * Fixes this bug in Locale::Simple:
    https://rt.cpan.org/Ticket/Display.html?id=127675
* Wed Nov  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- update to bug-fix version 1.30
  * Drop disable-broken-04find_domain_bug-test.patch (integrated upstream)
* Thu Nov  1 2018 Vítězslav Čížek <vcizek@suse.com>
- Disable 04find_domain_bug test broken with glibc 2.28
  * https://github.com/gflohr/libintl-perl/issues/3
  * add disable-broken-04find_domain_bug-test.patch
* Fri Nov 10 2017 coolo@suse.com
- updated to 1.29
  see /usr/share/doc/packages/perl-libintl-perl/Changes
* Fri Sep  1 2017 coolo@suse.com
- updated to 1.28
  see /usr/share/doc/packages/perl-libintl-perl/ChangeLog
    editorial changes
    use new class methods for xgettext options
    quote import tags in docs
    updated copyright date
    updated FAQ
    new class methods options, flags, and keywords
    This will produce the default keyword and flag definitions for xgettext
    for Locale::TextDomain.
* Wed Aug  9 2017 coolo@suse.com
- updated to 1.27
  see /usr/share/doc/packages/perl-libintl-perl/ChangeLog
* Thu Jun 23 2016 coolo@suse.com
- updated to 1.26
  * Fixed more false negatives in tests, no need to upgrade.
* Wed Jun  1 2016 coolo@suse.com
- update to 1.25
  * Fixed false negatives in test suite, no need to upgrade the module!
  * Bugs fixed:
    https://rt.cpan.org/Ticket/Display.html?id=83980
    https://rt.cpan.org/Ticket/Display.html?id=47968
* Thu Sep 24 2015 coolo@suse.com
- update to 1.24
  * Better portability for tests.
  * Updated documentation.
  * License changed to GPLv3.
  * Bugs fixed:
    https://rt.cpan.org/Ticket/Display.html?id=98109
    https://rt.cpan.org/Ticket/Display.html?id=47968
    https://rt.cpan.org/Ticket/Display.html?id=83980
    https://rt.cpan.org/Ticket/Display.html?id=102288
  Version 1.23 - 24 Jan 2013
  * New message retrieval backend Locale::gettext_dumb(3pm) which produces
    translations even, when the corresponding locale is not present in
    the system.
  * Fixed a bug where the Perl backend under certain circumstances clobbered
    the environment variable LC_ALL.
  * Avoid test failures by skipping all tests that depend on the de_AT
    locale, when that locale is not installed.
  * Bugs fixed:
    https://rt.cpan.org/Ticket/Display.html?id=82856
  Version 1.22 - 24 Jan 2013
  * Version 1.22 outsmarted PAUSE (the CPAN upload facility) and had to
    be removed.
  Version 1.21 - 15 Jan 2013
  * Environment variables LANGUAGE and LANG are interpreted in the same way
    in the XS and the pure Perl version.
  * Package design closer to GNU standards.
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Tue Dec  8 2009 jengelh@medozas.de
- enable parallel building
* Mon Sep  7 2009 mls@suse.de
- update to libintl-perl-1.20
  * many test failures fixed
  * Fixed RT bug #46471, noop functions in scalar context.
* Fri Jul 10 2009 jansimon.moeller@opensuse.org
- Remove blocking test. It hangs qemu-arm and stalls the worker.
  rm  ./tests/04find_domain_bug.t
* Sun Nov 25 2007 ro@suse.de
- adapt requires to gettext rename (gettext-runtime)
* Fri Nov  9 2007 pth@suse.de
- Initial package, needed by gettext testsuite
